/*	$NetBSD: msg_287.c,v 1.3 2022/06/16 21:24:41 rillig Exp $	*/
# 3 "msg_287.c"

// Test for message: function declaration is not a prototype [287]

/* expect+1: error: syntax error ':' [249] */
TODO: "Add example code that triggers the above message."
TODO: "Add example code that almost triggers the above message."
